==> huaweicloudsdkvod-3.1.117-py2.py3-none-any.whl: huaweicloudsdkvod/v1/model/list_watermark_template_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListWatermarkTemplateResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'templates': 'list[WatermarkTemplate]',
        'total': 'int'
    }

    attribute_map = {
        'templates': 'templates',
        'total': 'total'
    }

    def __init__(self, templates=None, total=None):
        """ListWatermarkTemplateResponse

        The model defined in huaweicloud sdk

        :param templates: 水印模板信息。
        :type templates: list[:class:`huaweicloudsdkvod.v1.WatermarkTemplate`]
        :param total: 总数。
        :type total: int
        """
        
        super(ListWatermarkTemplateResponse, self).__init__()

        self._templates = None
        self._total = None
        self.discriminator = None

        if templates is not None:
            self.templates = templates
        if total is not None:
            self.total = total

    @property
    def templates(self):
        """Gets the templates of this ListWatermarkTemplateResponse.

        水印模板信息。

        :return: The templates of this ListWatermarkTemplateResponse.
        :rtype: list[:class:`huaweicloudsdkvod.v1.WatermarkTemplate`]
        """
        return self._templates

    @templates.setter
    def templates(self, templates):
        """Sets the templates of this ListWatermarkTemplateResponse.

        水印模板信息。

        :param templates: The templates of this ListWatermarkTemplateResponse.
        :type templates: list[:class:`huaweicloudsdkvod.v1.WatermarkTemplate`]
        """
        self._templates = templates

    @property
    def total(self):
        """Gets the total of this ListWatermarkTemplateResponse.

        总数。

        :return: The total of this ListWatermarkTemplateResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListWatermarkTemplateResponse.

        总数。

        :param total: The total of this ListWatermarkTemplateResponse.
        :type total: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListWatermarkTemplateResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvod-3.1.147-py2.py3-none-any.whl: huaweicloudsdkvod/v1/model/list_watermark_template_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListWatermarkTemplateResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'templates': 'list[WatermarkTemplate]',
        'total': 'int'
    }

    attribute_map = {
        'templates': 'templates',
        'total': 'total'
    }

    def __init__(self, templates=None, total=None):
        r"""ListWatermarkTemplateResponse

        The model defined in huaweicloud sdk

        :param templates: 水印模板信息。
        :type templates: list[:class:`huaweicloudsdkvod.v1.WatermarkTemplate`]
        :param total: 总数。
        :type total: int
        """
        
        super(ListWatermarkTemplateResponse, self).__init__()

        self._templates = None
        self._total = None
        self.discriminator = None

        if templates is not None:
            self.templates = templates
        if total is not None:
            self.total = total

    @property
    def templates(self):
        r"""Gets the templates of this ListWatermarkTemplateResponse.

        水印模板信息。

        :return: The templates of this ListWatermarkTemplateResponse.
        :rtype: list[:class:`huaweicloudsdkvod.v1.WatermarkTemplate`]
        """
        return self._templates

    @templates.setter
    def templates(self, templates):
        r"""Sets the templates of this ListWatermarkTemplateResponse.

        水印模板信息。

        :param templates: The templates of this ListWatermarkTemplateResponse.
        :type templates: list[:class:`huaweicloudsdkvod.v1.WatermarkTemplate`]
        """
        self._templates = templates

    @property
    def total(self):
        r"""Gets the total of this ListWatermarkTemplateResponse.

        总数。

        :return: The total of this ListWatermarkTemplateResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListWatermarkTemplateResponse.

        总数。

        :param total: The total of this ListWatermarkTemplateResponse.
        :type total: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListWatermarkTemplateResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
